@@ -6,7 +6,19 @@ ARCH=$1 # amd or arm
 VERSION=$2 # Full yubico-piv-tool version, tex 2.1.0
 SO_VERSION=$3
 
-BREW_LIB="/opt/homebrew/opt"
+if [ "$ARCH" == "amd" ]; then
+  BREW_LIB="/usr/local/opt"
+  #BREW_CELLAR="/usr/local/Cellar"
+elif [ "$ARCH" == "arm" ]; then
+  BREW_LIB="/opt/homebrew/opt"
+  #BREW_CELLAR="/opt/homebrew/Cellar"
+else
+  echo "Unknown architecture"
+  exit
+fi
+
+echo "BREW_LIB: $BREW_LIB"
+ls $BREW_LIB
 
 export PKG_CONFIG_PATH=$BREW_LIB/openssl/lib/pkgconfig
 
